@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: zapfdingbats.pm,v 1.5 2004/06/15 09:14:54 fredo Exp $
+#   $Id: zapfdingbats.pm,v 1.6 2004/12/16 01:09:24 fredo Exp $
 #
 #=======================================================================
 
@@ -310,208 +310,208 @@ $fonts->{zapfdingbats}= {
     ], # DEF. ENCODING GLYPH TABLE
     'fontbbox' => [ 0, -143, 981, 820 ],
     'wx' => { # HORIZ. WIDTH TABLE
-        'space' => '250',                        # C+0x20 # U+0xF020
-        'a1' => '1000',                          # C+0x21 # U+0xF021
-        'a2' => '1000',                          # C+0x22 # U+0xF022
-        'a202' => '1000',                        # C+0x23 # U+0xF023
-        'a3' => '1000',                          # C+0x24 # U+0xF024
-        'a4' => '833',                           # C+0x25 # U+0xF025
-        'a5' => '943',                           # C+0x26 # U+0xF026
-        'a119' => '833',                         # C+0x27 # U+0xF027
-        'a118' => '889',                         # C+0x28 # U+0xF028
-        'a117' => '1000',                        # C+0x29 # U+0xF029
-        'a11' => '1000',                         # C+0x2A # U+0xF02A
-        'a12' => '1000',                         # C+0x2B # U+0xF02B
-        'a13' => '666',                          # C+0x2C # U+0xF02C
-        'a14' => '1000',                         # C+0x2D # U+0xF02D
-        'a15' => '1000',                         # C+0x2E # U+0xF02E
-        'a16' => '1000',                         # C+0x2F # U+0xF02F
-        'a105' => '1000',                        # C+0x30 # U+0xF030
-        'a17' => '1000',                         # C+0x31 # U+0xF031
-        'a18' => '1000',                         # C+0x32 # U+0xF032
-        'a19' => '777',                          # C+0x33 # U+0xF033
-        'a20' => '943',                          # C+0x34 # U+0xF034
-        'a21' => '833',                          # C+0x35 # U+0xF035
-        'a22' => '1000',                         # C+0x36 # U+0xF036
-        'a23' => '777',                          # C+0x37 # U+0xF037
-        'a24' => '833',                          # C+0x38 # U+0xF038
-        'a25' => '889',                          # C+0x39 # U+0xF039
-        'a26' => '889',                          # C+0x3A # U+0xF03A
-        'a27' => '833',                          # C+0x3B # U+0xF03B
-        'a28' => '855',                          # C+0x3C # U+0xF03C
-        'a6' => '556',                           # C+0x3D # U+0xF03D
-        'a7' => '722',                           # C+0x3E # U+0xF03E
-        'a8' => '722',                           # C+0x3F # U+0xF03F
-        'a9' => '777',                           # C+0x40 # U+0xF040
-        'a10' => '777',                          # C+0x41 # U+0xF041
-        'a29' => '833',                          # C+0x42 # U+0xF042
-        'a30' => '889',                          # C+0x43 # U+0xF043
-        'a31' => '889',                          # C+0x44 # U+0xF044
-        'a32' => '833',                          # C+0x45 # U+0xF045
-        'a33' => '889',                          # C+0x46 # U+0xF046
-        'a34' => '889',                          # C+0x47 # U+0xF047
-        'a35' => '876',                          # C+0x48 # U+0xF048
-        'a36' => '876',                          # C+0x49 # U+0xF049
-        'a37' => '833',                          # C+0x4A # U+0xF04A
-        'a38' => '889',                          # C+0x4B # U+0xF04B
-        'a39' => '943',                          # C+0x4C # U+0xF04C
-        'a40' => '889',                          # C+0x4D # U+0xF04D
-        'a41' => '889',                          # C+0x4E # U+0xF04E
-        'a42' => '889',                          # C+0x4F # U+0xF04F
-        'a43' => '943',                          # C+0x50 # U+0xF050
-        'a44' => '708',                          # C+0x51 # U+0xF051
-        'a45' => '708',                          # C+0x52 # U+0xF052
-        'a46' => '889',                          # C+0x53 # U+0xF053
-        'a47' => '889',                          # C+0x54 # U+0xF054
-        'a48' => '1000',                         # C+0x55 # U+0xF055
-        'a49' => '833',                          # C+0x56 # U+0xF056
-        'a50' => '889',                          # C+0x57 # U+0xF057
-        'a51' => '876',                          # C+0x58 # U+0xF058
-        'a52' => '876',                          # C+0x59 # U+0xF059
-        'a53' => '889',                          # C+0x5A # U+0xF05A
-        'a54' => '708',                          # C+0x5B # U+0xF05B
-        'a55' => '777',                          # C+0x5C # U+0xF05C
-        'a56' => '708',                          # C+0x5D # U+0xF05D
-        'a57' => '777',                          # C+0x5E # U+0xF05E
-        'a58' => '833',                          # C+0x5F # U+0xF05F
-        'a59' => '889',                          # C+0x60 # U+0xF060
-        'a60' => '943',                          # C+0x61 # U+0xF061
-        'a61' => '833',                          # C+0x62 # U+0xF062
-        'a62' => '777',                          # C+0x63 # U+0xF063
-        'a63' => '833',                          # C+0x64 # U+0xF064
-        'a64' => '777',                          # C+0x65 # U+0xF065
-        'a65' => '777',                          # C+0x66 # U+0xF066
-        'a66' => '777',                          # C+0x67 # U+0xF067
-        'a67' => '777',                          # C+0x68 # U+0xF068
-        'a68' => '722',                          # C+0x69 # U+0xF069
-        'a69' => '833',                          # C+0x6A # U+0xF06A
-        'a70' => '833',                          # C+0x6B # U+0xF06B
-        'a71' => '1000',                         # C+0x6C # U+0xF06C
-        'a72' => '907',                          # C+0x6D # U+0xF06D
-        'a73' => '1000',                         # C+0x6E # U+0xF06E
-        'a74' => '1000',                         # C+0x6F # U+0xF06F
-        'a203' => '1000',                        # C+0x70 # U+0xF070
-        'a75' => '1000',                         # C+0x71 # U+0xF071
-        'a204' => '1000',                        # C+0x72 # U+0xF072
-        'a76' => '1000',                         # C+0x73 # U+0xF073
-        'a77' => '1000',                         # C+0x74 # U+0xF074
-        'a78' => '1000',                         # C+0x75 # U+0xF075
-        'a79' => '833',                          # C+0x76 # U+0xF076
-        'a81' => '500',                          # C+0x77 # U+0xF077
-        'a82' => '230',                          # C+0x78 # U+0xF078
-        'a83' => '399',                          # C+0x79 # U+0xF079
-        'a84' => '579',                          # C+0x7A # U+0xF07A
-        'a97' => '666',                          # C+0x7B # U+0xF07B
-        'a98' => '666',                          # C+0x7C # U+0xF07C
-        'a99' => '1000',                         # C+0x7D # U+0xF07D
-        'a100' => '1000',                        # C+0x7E # U+0xF07E
-        'a89' => '443',                          # C+0x80 # U+0xF080
-        'a90' => '443',                          # C+0x81 # U+0xF081
-        'a93' => '389',                          # C+0x82 # U+0xF082
-        'a94' => '389',                          # C+0x83 # U+0xF083
-        'a91' => '337',                          # C+0x84 # U+0xF084
-        'a92' => '337',                          # C+0x85 # U+0xF085
-        'a205' => '514',                         # C+0x86 # U+0xF086
-        'a85' => '514',                          # C+0x87 # U+0xF087
-        'a206' => '550',                         # C+0x88 # U+0xF088
-        'a86' => '550',                          # C+0x89 # U+0xF089
-        'a87' => '277',                          # C+0x8A # U+0xF08A
-        'a88' => '277',                          # C+0x8B # U+0xF08B
-        'a95' => '500',                          # C+0x8C # U+0xF08C
-        'a96' => '500',                          # C+0x8D # U+0xF08D
-        'a101' => '722',                         # C+0xA1 # U+0xF0A1
-        'a102' => '556',                         # C+0xA2 # U+0xF0A2
-        'a103' => '666',                         # C+0xA3 # U+0xF0A3
-        'a104' => '1000',                        # C+0xA4 # U+0xF0A4
-        'a106' => '722',                         # C+0xA5 # U+0xF0A5
-        'a107' => '1000',                        # C+0xA6 # U+0xF0A6
-        'a108' => '1000',                        # C+0xA7 # U+0xF0A7
-        'a112' => '777',                         # C+0xA8 # U+0xF0A8
-        'a111' => '777',                         # C+0xA9 # U+0xF0A9
-        'a110' => '777',                         # C+0xAA # U+0xF0AA
-        'a109' => '777',                         # C+0xAB # U+0xF0AB
-        'a120' => '821',                         # C+0xAC # U+0xF0AC
-        'a121' => '821',                         # C+0xAD # U+0xF0AD
-        'a122' => '821',                         # C+0xAE # U+0xF0AE
-        'a123' => '821',                         # C+0xAF # U+0xF0AF
-        'a124' => '821',                         # C+0xB0 # U+0xF0B0
-        'a125' => '821',                         # C+0xB1 # U+0xF0B1
-        'a126' => '821',                         # C+0xB2 # U+0xF0B2
-        'a127' => '821',                         # C+0xB3 # U+0xF0B3
-        'a128' => '821',                         # C+0xB4 # U+0xF0B4
-        'a129' => '821',                         # C+0xB5 # U+0xF0B5
-        'a130' => '821',                         # C+0xB6 # U+0xF0B6
-        'a131' => '821',                         # C+0xB7 # U+0xF0B7
-        'a132' => '821',                         # C+0xB8 # U+0xF0B8
-        'a133' => '821',                         # C+0xB9 # U+0xF0B9
-        'a134' => '821',                         # C+0xBA # U+0xF0BA
-        'a135' => '821',                         # C+0xBB # U+0xF0BB
-        'a136' => '821',                         # C+0xBC # U+0xF0BC
-        'a137' => '821',                         # C+0xBD # U+0xF0BD
-        'a138' => '821',                         # C+0xBE # U+0xF0BE
-        'a139' => '821',                         # C+0xBF # U+0xF0BF
-        'a140' => '821',                         # C+0xC0 # U+0xF0C0
-        'a141' => '821',                         # C+0xC1 # U+0xF0C1
-        'a142' => '821',                         # C+0xC2 # U+0xF0C2
-        'a143' => '821',                         # C+0xC3 # U+0xF0C3
-        'a144' => '821',                         # C+0xC4 # U+0xF0C4
-        'a145' => '821',                         # C+0xC5 # U+0xF0C5
-        'a146' => '821',                         # C+0xC6 # U+0xF0C6
-        'a147' => '821',                         # C+0xC7 # U+0xF0C7
-        'a148' => '821',                         # C+0xC8 # U+0xF0C8
-        'a149' => '821',                         # C+0xC9 # U+0xF0C9
-        'a150' => '821',                         # C+0xCA # U+0xF0CA
-        'a151' => '821',                         # C+0xCB # U+0xF0CB
-        'a152' => '821',                         # C+0xCC # U+0xF0CC
-        'a153' => '821',                         # C+0xCD # U+0xF0CD
-        'a154' => '821',                         # C+0xCE # U+0xF0CE
-        'a155' => '821',                         # C+0xCF # U+0xF0CF
-        'a156' => '821',                         # C+0xD0 # U+0xF0D0
-        'a157' => '821',                         # C+0xD1 # U+0xF0D1
-        'a158' => '821',                         # C+0xD2 # U+0xF0D2
-        'a159' => '821',                         # C+0xD3 # U+0xF0D3
-        'a160' => '1000',                        # C+0xD4 # U+0xF0D4
-        'a161' => '833',                         # C+0xD5 # U+0xF0D5
-        'a163' => '1000',                        # C+0xD6 # U+0xF0D6
-        'a164' => '416',                         # C+0xD7 # U+0xF0D7
-        'a196' => '889',                         # C+0xD8 # U+0xF0D8
-        'a165' => '1000',                        # C+0xD9 # U+0xF0D9
-        'a192' => '889',                         # C+0xDA # U+0xF0DA
-        'a166' => '1000',                        # C+0xDB # U+0xF0DB
-        'a167' => '1000',                        # C+0xDC # U+0xF0DC
-        'a168' => '1000',                        # C+0xDD # U+0xF0DD
-        'a169' => '1000',                        # C+0xDE # U+0xF0DE
-        'a170' => '1000',                        # C+0xDF # U+0xF0DF
-        'a171' => '1000',                        # C+0xE0 # U+0xF0E0
-        'a172' => '1000',                        # C+0xE1 # U+0xF0E1
-        'a173' => '1000',                        # C+0xE2 # U+0xF0E2
-        'a162' => '1000',                        # C+0xE3 # U+0xF0E3
-        'a174' => '1000',                        # C+0xE4 # U+0xF0E4
-        'a175' => '1000',                        # C+0xE5 # U+0xF0E5
-        'a176' => '1000',                        # C+0xE6 # U+0xF0E6
-        'a177' => '500',                         # C+0xE7 # U+0xF0E7
-        'a178' => '1000',                        # C+0xE8 # U+0xF0E8
-        'a179' => '1000',                        # C+0xE9 # U+0xF0E9
-        'a193' => '1000',                        # C+0xEA # U+0xF0EA
-        'a180' => '1000',                        # C+0xEB # U+0xF0EB
-        'a199' => '1000',                        # C+0xEC # U+0xF0EC
-        'a181' => '889',                         # C+0xED # U+0xF0ED
-        'a200' => '889',                         # C+0xEE # U+0xF0EE
-        'a182' => '1000',                        # C+0xEF # U+0xF0EF
-        'a201' => '1000',                        # C+0xF1 # U+0xF0F1
-        'a183' => '1000',                        # C+0xF2 # U+0xF0F2
-        'a184' => '1000',                        # C+0xF3 # U+0xF0F3
-        'a197' => '1000',                        # C+0xF4 # U+0xF0F4
-        'a185' => '1000',                        # C+0xF5 # U+0xF0F5
-        'a194' => '1000',                        # C+0xF6 # U+0xF0F6
-        'a198' => '943',                         # C+0xF7 # U+0xF0F7
-        'a186' => '1000',                        # C+0xF8 # U+0xF0F8
-        'a195' => '943',                         # C+0xF9 # U+0xF0F9
-        'a187' => '1000',                        # C+0xFA # U+0xF0FA
-        'a188' => '1000',                        # C+0xFB # U+0xF0FB
-        'a189' => '1000',                        # C+0xFC # U+0xF0FC
-        'a190' => '1000',                        # C+0xFD # U+0xF0FD
-        'a191' => '1000',                        # C+0xFE # U+0xF0FE
+        'space'              => 278,
+        'a1'                 => 974,
+        'a10'                => 692,
+        'a100'               => 668,
+        'a101'               => 732,
+        'a102'               => 544,
+        'a103'               => 544,
+        'a104'               => 910,
+        'a105'               => 911,
+        'a106'               => 667,
+        'a107'               => 760,
+        'a108'               => 760,
+        'a109'               => 626,
+        'a11'                => 960,
+        'a110'               => 694,
+        'a111'               => 595,
+        'a112'               => 776,
+        'a117'               => 690,
+        'a118'               => 791,
+        'a119'               => 790,
+        'a12'                => 939,
+        'a120'               => 788,
+        'a121'               => 788,
+        'a122'               => 788,
+        'a123'               => 788,
+        'a124'               => 788,
+        'a125'               => 788,
+        'a126'               => 788,
+        'a127'               => 788,
+        'a128'               => 788,
+        'a129'               => 788,
+        'a13'                => 549,
+        'a130'               => 788,
+        'a131'               => 788,
+        'a132'               => 788,
+        'a133'               => 788,
+        'a134'               => 788,
+        'a135'               => 788,
+        'a136'               => 788,
+        'a137'               => 788,
+        'a138'               => 788,
+        'a139'               => 788,
+        'a14'                => 855,
+        'a140'               => 788,
+        'a141'               => 788,
+        'a142'               => 788,
+        'a143'               => 788,
+        'a144'               => 788,
+        'a145'               => 788,
+        'a146'               => 788,
+        'a147'               => 788,
+        'a148'               => 788,
+        'a149'               => 788,
+        'a15'                => 911,
+        'a150'               => 788,
+        'a151'               => 788,
+        'a152'               => 788,
+        'a153'               => 788,
+        'a154'               => 788,
+        'a155'               => 788,
+        'a156'               => 788,
+        'a157'               => 788,
+        'a158'               => 788,
+        'a159'               => 788,
+        'a16'                => 933,
+        'a160'               => 894,
+        'a161'               => 838,
+        'a162'               => 924,
+        'a163'               => 1016,
+        'a164'               => 458,
+        'a165'               => 924,
+        'a166'               => 918,
+        'a167'               => 927,
+        'a168'               => 928,
+        'a169'               => 928,
+        'a17'                => 945,
+        'a170'               => 834,
+        'a171'               => 873,
+        'a172'               => 828,
+        'a173'               => 924,
+        'a174'               => 917,
+        'a175'               => 930,
+        'a176'               => 931,
+        'a177'               => 463,
+        'a178'               => 883,
+        'a179'               => 836,
+        'a18'                => 974,
+        'a180'               => 867,
+        'a181'               => 696,
+        'a182'               => 874,
+        'a183'               => 760,
+        'a184'               => 946,
+        'a185'               => 865,
+        'a186'               => 967,
+        'a187'               => 831,
+        'a188'               => 873,
+        'a189'               => 927,
+        'a19'                => 755,
+        'a190'               => 970,
+        'a191'               => 918,
+        'a192'               => 748,
+        'a193'               => 836,
+        'a194'               => 771,
+        'a195'               => 888,
+        'a196'               => 748,
+        'a197'               => 771,
+        'a198'               => 888,
+        'a199'               => 867,
+        'a2'                 => 961,
+        'a20'                => 846,
+        'a200'               => 696,
+        'a201'               => 874,
+        'a202'               => 974,
+        'a203'               => 762,
+        'a204'               => 759,
+        'a205'               => 509,
+        'a206'               => 410,
+        'a21'                => 762,
+        'a22'                => 761,
+        'a23'                => 571,
+        'a24'                => 677,
+        'a25'                => 763,
+        'a26'                => 760,
+        'a27'                => 759,
+        'a28'                => 754,
+        'a29'                => 786,
+        'a3'                 => 980,
+        'a30'                => 788,
+        'a31'                => 788,
+        'a32'                => 790,
+        'a33'                => 793,
+        'a34'                => 794,
+        'a35'                => 816,
+        'a36'                => 823,
+        'a37'                => 789,
+        'a38'                => 841,
+        'a39'                => 823,
+        'a4'                 => 719,
+        'a40'                => 833,
+        'a41'                => 816,
+        'a42'                => 831,
+        'a43'                => 923,
+        'a44'                => 744,
+        'a45'                => 723,
+        'a46'                => 749,
+        'a47'                => 790,
+        'a48'                => 792,
+        'a49'                => 695,
+        'a5'                 => 789,
+        'a50'                => 776,
+        'a51'                => 768,
+        'a52'                => 792,
+        'a53'                => 759,
+        'a54'                => 707,
+        'a55'                => 708,
+        'a56'                => 682,
+        'a57'                => 701,
+        'a58'                => 826,
+        'a59'                => 815,
+        'a6'                 => 494,
+        'a60'                => 789,
+        'a61'                => 789,
+        'a62'                => 707,
+        'a63'                => 687,
+        'a64'                => 696,
+        'a65'                => 689,
+        'a66'                => 786,
+        'a67'                => 787,
+        'a68'                => 713,
+        'a69'                => 791,
+        'a7'                 => 552,
+        'a70'                => 785,
+        'a71'                => 791,
+        'a72'                => 873,
+        'a73'                => 761,
+        'a74'                => 762,
+        'a75'                => 759,
+        'a76'                => 892,
+        'a77'                => 892,
+        'a78'                => 788,
+        'a79'                => 784,
+        'a8'                 => 537,
+        'a81'                => 438,
+        'a82'                => 138,
+        'a83'                => 277,
+        'a84'                => 415,
+        'a85'                => 509,
+        'a86'                => 410,
+        'a87'                => 234,
+        'a88'                => 234,
+        'a89'                => 390,
+        'a9'                 => 577,
+        'a90'                => 390,
+        'a91'                => 276,
+        'a92'                => 276,
+        'a93'                => 317,
+        'a94'                => 317,
+        'a95'                => 334,
+        'a96'                => 334,
+        'a97'                => 392,
+        'a98'                => 392,
+        'a99'                => 668,
     }, # HORIZ. WIDTH TABLE
 };
 
@@ -525,6 +525,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: zapfdingbats.pm,v $
+    Revision 1.6  2004/12/16 01:09:24  fredo
+    updated to new adobe afm
+
     Revision 1.5  2004/06/15 09:14:54  fredo
     removed cr+lf
 
