@@ -27,21 +27,23 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: Win32.pm,v 1.6 2004/06/15 09:11:38 fredo Exp $
+#   $Id: Win32.pm,v 1.7 2004/12/16 00:30:52 fredo Exp $
 #
 #=======================================================================
 
 package PDF::API2::Win32;
 
     use vars qw($VERSION);
-    ( $VERSION ) = '$Revision: 1.6 $' =~ /Revision: (\S+)\s/; # $Date: 2004/06/15 09:11:38 $
+    ( $VERSION ) = '$Revision: 1.7 $' =~ /Revision: (\S+)\s/; # $Date: 2004/12/16 00:30:52 $
 
+    no warnings qw[ deprecated recursion uninitialized ];
 
 package PDF::API2;
 
 use vars qw( $wf );
 use Win32::TieRegistry;
 
+no warnings qw[ deprecated recursion uninitialized ];
 
 $wf={};
 
@@ -118,6 +120,9 @@ __END__
 =head1 HISTORY
 
     $Log: Win32.pm,v $
+    Revision 1.7  2004/12/16 00:30:52  fredo
+    added no warn for recursion
+
     Revision 1.6  2004/06/15 09:11:38  fredo
     removed cr+lf
 
